#
# spec file for package molecule
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%if 0%{?suse_version} < 1550
# Leap15, SLES15
%if %pythons == "python310"
%define ansible_python python310
%define ansible_python_executable python3.10
%define ansible_python_sitelib %python310_sitelib
%endif
%if %pythons == "python311"
%define ansible_python python311
%define ansible_python_executable python3.11
%define ansible_python_sitelib %python311_sitelib
%endif
%else
# Tumbleweed
%define pythons python3
%define ansible_python python3
%define ansible_python_executable python3
%define ansible_python_sitelib %python3_sitelib
%endif

%bcond_without test
Name:           molecule
Version:        24.7.0
Release:        1.1
Summary:        Aids in the development and testing of Ansible roles
License:        MIT
URL:            https://github.com/ansible-community/molecule
Source:         https://files.pythonhosted.org/packages/source/m/molecule/molecule-%{version}.tar.gz
BuildRequires:  python-rpm-macros
BuildRequires:  %{ansible_python}-base >= 3.10
BuildRequires:  %{ansible_python}-pip
BuildRequires:  %{ansible_python}-setuptools
BuildRequires:  %{ansible_python}-wheel
%if %{with test}
BuildRequires:  git-core
BuildRequires:  ansible-lint >= 6.12.1
BuildRequires:  %{ansible_python}-ansi2html >= 1.8.0
BuildRequires:  %{ansible_python}-coverage >= 7.0.3
BuildRequires:  %{ansible_python}-filelock >= 3.9.0
BuildRequires:  %{ansible_python}-pexpect >= 4.8.0
BuildRequires:  %{ansible_python}-pytest >= 7.2.0
BuildRequires:  %{ansible_python}-pytest-mock >= 3.10.0
BuildRequires:  %{ansible_python}-pytest-plus >= 0.4.0
BuildRequires:  %{ansible_python}-pytest-xdist >= 3.1.0
BuildRequires:  %{ansible_python}-yamllint
%endif
# add runtime dependencies of molecule as BuildRequires
# https://github.com/ansible/molecule/blob/main/.config/requirements.in
BuildRequires:  %{ansible_python}-base >= 3.9
BuildRequires:  ansible-core >= 2.12.10
BuildRequires:  %{ansible_python}-ansible-compat >= 24.6.1
BuildRequires:  %{ansible_python}-click >= 8.0
BuildRequires:  %{ansible_python}-click-help-colors >= 0.9
BuildRequires:  %{ansible_python}-enrich >= 1.2.7
BuildRequires:  %{ansible_python}-jsonschema >= 4.9.1
BuildRequires:  %{ansible_python}-Jinja2 >= 2.11.3
BuildRequires:  %{ansible_python}-packaging
BuildRequires:  %{ansible_python}-pluggy >= 0.7.1
BuildRequires:  %{ansible_python}-PyYAML >= 5.1
BuildRequires:  %{ansible_python}-rich >= 9.5.1
BuildRequires:  %{ansible_python}-wcmatch >= 8.1.2
BuildRequires:  fdupes
# https://github.com/ansible/molecule/blob/main/.config/requirements.in
Requires:       %{ansible_python}-base >= 3.9
Requires:       %{ansible_python}-ansible-compat >= 24.6.1
Requires:       ansible-core >= 2.12.10
Requires:       %{ansible_python}-click >= 8.0
Requires:       %{ansible_python}-click-help-colors >= 0.9
Requires:       %{ansible_python}-enrich >= 1.2.7
Requires:       %{ansible_python}-jsonschema >= 4.9.1
Requires:       %{ansible_python}-Jinja2 >= 2.11.3
Requires:       %{ansible_python}-packaging
Requires:       %{ansible_python}-pluggy >= 0.7.1
Requires:       %{ansible_python}-PyYAML >= 5.1
Requires:       %{ansible_python}-rich >= 9.5.1
Requires:       %{ansible_python}-wcmatch >= 8.1.2
BuildArch:      noarch

%description
Molecule project is designed to aid in the development and testing of
Ansible roles.

Molecule provides support for testing with multiple instances, operating
systems and distributions, virtualization providers, test frameworks and
testing scenarios.

%prep
%autosetup -p 1 -n molecule-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{ansible_python_sitelib}

%check
%if %{with test}
export PATH="%{buildroot}%{_bindir}:$PATH"
sed -i '/^addopts/s/ --color=yes//' pyproject.toml

IGNORED_CHECKS="test_podman"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command_dependency"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command_init_role[delegated]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command_init_scenario[delegated]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_docker"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_molecule_schema"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_sample_collection"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_with_and_without_gitignore[test_w_gitignore]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_execute_cmdline_scenarios"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_execute_cmdline_scenarios_prune"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_execute_cmdline_scenarios_no_prune"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_execute_cmdline_scenarios_exit_destroy"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_execute_cmdline_scenarios_exit_nodestroy"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_ansible_connection_options_when_managed[_driver_managed_section_data]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command[check-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command[cleanup-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command[converge-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command[create-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command[destroy-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command[prepare-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command[syntax-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command[side-effect-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command[test-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command[verify-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command_idempotence[0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command_init_scenario"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_command_list_with_format_plain"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_with_missing_platform_name[instance-False-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_with_missing_platform_name[gonzo-True-0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_role_name_check_one"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scenario_execute"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_get_modules_directories_default"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_get_filter_plugins_directories_default"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_absolute_path_for"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_converge_property"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_get_playbook"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_get_configs"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_playbooks_converge_property"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_get_ansible_playbook_with_driver_key_when_playbook_key_missing[_provisioner_driver_playbook_key_missing_section_data]"

%pytest -k "not (${IGNORED_CHECKS})" -W ignore:'There is no current event loop'
%endif

%files
%license LICENSE
%{ansible_python_sitelib}/*
%{_bindir}/molecule

%changelog
* Thu Jul 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.7.0:
  Bugfixes
  * Updated cspell dictionary and removed unneeded values (#4251)
    @alisonlhart
* Thu Jul 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.6.1:
  Bugfixes
  * Restore examples in docs (#4221) @cidrblock
* Fri Jun  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.6.0:
  Bugfixes
  * Respect ANSIBLE_COLLECTIONS_PATH (#4192) @cidrblock
  * Avoid requests 2.32.0 during testing (#4185) @ssbarnea
  * Update configuration.md for role name check (#4155)
    @AlexanderStohr
  * Added more dynamic arguments to podman container creation
    playbook (#4169) @felipe4334
  * Always apply ssh_connection_options (#4174) @wokis
  * Link to the parallel.md, not docker-rootless.md for parallel
    example (#4168) @evgeni
  * Fix test method name. (#4165) @expeehaa
* Wed Apr 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.2.1:
  Bugfixes
  * Molecule uses ANSIBLE_FILTER_PLUGINS
    (#4135 <https://github.com/ansible/molecule/pull/4135>)
  * Set ANSIBLE_FORCE_COLOR sooner to fix missing color output in
    tmux
    (#4145 <https://github.com/ansible/molecule/pull/4145>)
  * Fix symlinks creation in ansible provisioneer
    (#4134 <https://github.com/ansible/molecule/pull/4134>)
* Thu Mar 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- ignore 5 tests that started to fail
* Thu Feb  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.2.0 (new naming scheme upstream):
  * Major Changes
  - Set Python 3.10 as minimum version (#4099) @cristianonicolai
  * Minor Changes
  - Adding molecule template based on driver.name (#4126)
    @mrbrandao
  * Bugfixes
  - Fix background color on matrix command (#4133) @ssbarnea
  - Fix python interpreter for scenario init (#4111) @dobbi84
  - Drivers command now display more information (#4112)
    @ssbarnea
  - Fix indents in Getting Started example playbook (#4104)
    @akira6592
  - Restructure documentation (#4102) @ssbarnea
* Wed Dec 13 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 6.0.3:
  * Bugfixes
  - Change molecule_inventory in podman example to remove ansible
    warning (#4086) @buckaroogeek
  - Update collection structure image in the docs (#4098)
    @ajinkyau
  - Enable ansible-lint (#4069) @ssbarnea
  - Correct git-archival settings (#4071) @ssbarnea
  - Docs: highlight importance of ansible_collections at root dir
    (#4060) @felher
  - Skip create step when created == true (#4038) @mluzarreta
  - Address ansible-lint reported issues (#4056) @muellerbe
  - Add podman driver option to podman config (#4062) @brandor5
  - Fix docker and podman examples to work with multiple
    platforms (#4068) @clickthisnick
  - Update docs to remove references to Docker being the default
    driver (#4065) @Qalthos
  - Fix forbidden implicit octal value (#4049) @jooola
  - Pin linkchecker version (#4050) @zhan9san
  - Update getting-started.md (#4030) @aogier
  - Address documentation username typo (#4031) @iamgini
- remove patch 4ab4f1c7_improve_test_names.patch that was taken
  from upstream originally and is included in this release
* Mon Nov 13 2023 Johannes Kastl <kastl@b1-systems.de>
- add patch 4ab4f1c7_improve_test_names.patch
  https://github.com/ansible/molecule/commit/4ab4f1c76fca978485ba63c67c944c489277aa0d
  to fix the pytest failures due to test names and duplicates
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 6.0.2:
  * Bugfixes
  - Update the getting started guide (#4023) @ajinkyau
  - Update ansible-compat to v4.1.7 (#4022) @ajinkyau
- drop Requires and BuildRequires that are no longer needed
- add Requires for wcmatch >= 8.1.2
- ignore some more pytest checks that cannot be run in OBS as they
  required podman/docker etc.
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 6.0.1:
  * Bugfixes
  - Pass environment in testinfra (#4014) @zhan9san
  - fix: remove `role` from `init` help info (#4010) @chenrui333
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 6.0.0:
  * Major Changes
  - Change current directory to scenario before running playbooks
    (#3966) @ssbarnea
  - Temporary disable support for external drivers (#3961)
    @ssbarnea
  - Reimplemented templating (init command) (#3959) @ssbarnea
  - Remove ability to configure collections-path and roles-path
    for dependency (#3956) @ssbarnea
  * Minor Changes
  - Allow molecule to list scenarios present under molecule
    directory within a collection (#3989) @ajinkyau
  - Avoid skipping create and destroy steps on delegated (#3949)
    @ssbarnea
  * Bugfixes
  - Ignore scenarios in virtual envrionments (#3996) @ajinkyau
  - Scaffold future docs structure (#3997) @cidrblock
  - Update documentation (#3985) @ajinkyau
  - Add example of integration with kubevirt (#3972) @jangel97
  - Make pytest-testinfra as an optional dependency (#3982)
    @ajinkyau
  - Dependency installation directory is changed (#3980)
    @zhan9san
  - Avoid reinstalling dependencies (#3979) @zhan9san
  - Remove constraints requirement files (#3981) @zhan9san
  - Add example of using docker collection using default driver
    (#3978) @zhan9san
  - Update documentation (#3975) @ajinkyau
  - Fix connection plugin name setting (#3957) @apatard
  - Disable isolation from ansible-compat Runtime (#3962)
    @ssbarnea
  - Add example of using podman collection using default driver
    (#3947) @ssbarnea
  - Improve how executed commands are logged (#3948) @ssbarnea
  - Make driver optional in molecule.yml file (#3946) @ssbarnea
* Mon Jun 26 2023 Johannes Kastl <kastl@b1-systems.de>
- remove fix_ansible_compat.patch that is no longer needed
- update to 5.1.0:
  * Minor Changes
  - Ensure external drivers are installed (#3901) @apatard
  - Update dependency doc (#3916) @zhan9san
  - Improve documentation for upgrade scenario (#3899) @fauust
  * Bugfixes
  - Fix documentation links (#3940) @ssbarnea
  - Fix quoted strings templating (#3911) @samiam
  - Adds Support for Shell Type Instance Param to Delegated
    Driver (#3932) @zollo
  - Fix dead link in documentation (#3923) @rtakasuke
  - Use backwards incompatible change from ansible-compat 4.0.1
    (#3904) @asmacdo
* Mon May 22 2023 Lukas Müller <expeehaa@outlook.com>
- Add fix_ansible_compat.patch from upstream pull request to fix
  compatibility with python-ansible-compat v4.
* Tue May 16 2023 Johannes Kastl <kastl@b1-systems.de>
- modify %%if-condition to allow building for python3.10 or
  python3.11 on SLES15
* Wed May 10 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 5.0.1:
  * Bugfixes
  - Avoid using incompatible ansible-compat version (#3906)
    @ssbarnea
  - Fix tree example in use case document (#3894) @akira6592
  - Use api to get driver schema file (#3898) @apatard
  - Add subprocess-run-check (#3896) @Ruchip16
  - Add unidiomatic-typecheck check (#3893) @Ruchip16
  - Add unnecessary-lambda check (#3892) @Ruchip16
  - Address ruff S, EXE skips (#3889) @ssbarnea
  - More ruff fixes (#3887) @ssbarnea
  - Fix colors when displaying plugin versions (#3886) @ssbarnea
  - Add raise-missing-from rule (#3885) @Ruchip16
  - Add no-else-return, no-else-raise & logging-not-lazy check
    (#3884) @Ruchip16
  - Add implicit-str-concat & inconsistent-return-statements
    check (#3882) @Ruchip16
* Wed May 10 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 5.0.0:
  * Major Changes
  - Remove lint command (#3802) @ssbarnea
  * Minor Changes
  - Add tags document (#3866) @zhan9san
  - Replace sphinx documentation with mkdocs (#3811) @ssbarnea
  - Require ansible-core>=2.12.10 (#3799) @ssbarnea
  - Remove support for python3.8 (#3770) @ssbarnea
  - Adopt PEP-621 for packaging (#3767) @ssbarnea
  * Bugfixes
  - Refactor dependency locks (#3879) @ssbarnea
  - Add consider-using-in check (#3880) @Ruchip16
  - Extend schema validation (#3765) @zhan9san
  - fix link to monorepo under faq (#3863) @ahmedwonolo
  - Fix documentation (#3833) @ziegenberg
  - Documentation: Improve group names (#3812) @ltog
  - Better indentation in verify template (#3816) @muellerbe
  - Replace sphinx documentation with mkdocs (#3811) @ssbarnea
  - Remove embedded dockerfile (#3824) @ssbarnea
  - Upgrade linters (#3813)
  - Add support for custom driver name (#3795) @gciavarrini
  - Document molecule-plugins package (#3805) @ssbarnea
  - Update test dependencies (#3800) @ssbarnea
  - Fix rpm building (#3798) @ssbarnea
  - Reorder heading and reformat badges (#3778) @mamercad
  - Fixed typo in docs/ci.rst (#3796) @mitchellroe
  - Bump test dependencies (#3797) @ssbarnea
  * Deprecations
  - Remove lint command (#3802) @ssbarnea
- drop patch skip-broken-test.patch
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add macro definitions to allow building for SLES15 with
  python3.11 instead of python3
* Sun Jan 29 2023 Lukas Müller <expeehaa@outlook.com>
- Disable deprecation warnings and tests requiring internet connection.
- Update to version 4.0.4.
  Changelog: https://github.com/ansible-community/molecule/releases/tag/v4.0.4
  * Allow side_effect and verify to have parameters (#3730) @ehartmann
  * Fix running tox:dockerfile with docker secretservice enabled (#3764) @zeitounator
  * Add some FQCNs (#3750) @muellerbe
  * Accept any string for "network_mode" in molecule.json schema (#3725) @fredflev
  * Fix moved libera channel (#3727) @staticdev
  * Add "default" as a valid docker "network_mode" in molecule.json schema (#3724) @fredflev
  * JSON Schema: Allow additionalProperties in ProvisionerConfigOptionsSshConnectionModel (#3721) @fredflev
  * Help messages when config does not match state file (#3713) @scottalreadytaken
  * Re-add credentials to Docker registry schema (#3706) @TheLastProject
  Changes from version 4.0.3:
  Changelog: https://github.com/ansible-community/molecule/releases/tag/v4.0.3
  * Add support for cgroupns_mode (#3700) @zhan9san
  * Platform env expects a dict of vars (#3690) @zeitounator
  * Support ANSIBLE_COLLECTIONS_PATH environment var (#3681) @nre-ableton
  * Fix schema (#3687) @jsf9k
  * Bump ansible-compat from 2.2.0 to 2.2.1 (#3670)
  Changes from version 4.0.2:
  Changelog: https://github.com/ansible-community/molecule/releases/tag/v4.0.2
  * Use FQCN at any point I found (#3680) @muellerbe
  * Schema fix (#3671) @apatard
  * Adopt molecule config JSON schema (#3668) @ssbarnea
  * Replace cerberus with jsonschema for configuration validation (#3638) @zhan9san
  * Downgrade log level when linking Ansible variables (#3646) @sleiner
  Changes from version 4.0.1:
  Changelog: https://github.com/ansible-community/molecule/releases/tag/v4.0.1
  * Add support for Python 3.11 (#3621) @ssbarnea
  * Added clarifications about customizing docker images (#3604) @timblaktu
  * Fix undocumented env vars (#3600) @gardar
  * Document description for action arguments (verify and side_effect) (#3605) @amarao
  Changes from version 4.0.0:
  Full Changelog: https://github.com/ansible-community/molecule/releases/tag/v4.0.0
  * Removed mol command line alias (#3457) @ssbarnea
  * Remove ansible and ansible-base extras (#3395) @ssbarnea
  * Remove support for py36 and py37 (#3436) @ssbarnea
  * Allow bypassing role name checking (#3549) @zhan9san
  * Add support for MOLECULE_PLATFORM_NAME (#3416) @zhan9san
  * Add args for verify and side_effect actions (#3467) @amarao
  * Enable packit rpm building for Fedora 35 (#3456) @ssbarnea
  * Remove ansible and ansible-base extras (#3395) @ssbarnea
* Tue Jul 26 2022 Lukas Müller <expeehaa@outlook.com>
- Disable tests on Leap.
* Mon Jun 20 2022 Lukas Müller <expeehaa@outlook.com>
- Add patch to skip a broken test in TW with Python 3.10.
* Thu Apr 28 2022 Lukas Müller <expeehaa@outlook.com>
- Create initial package.
